@@ -7,4 +7,6 @@ from .base import imread
 from .base import imsave
 from .opencv import cv_imshow
 from .opencv import cv_waitkey
+from .pil import pil_imshow
+from .pyplot import pyplot_imshow
 from .pyplot import pyplot_to_numpy
